<?php
/*
This file is part of Thomas Bley's moregroupware webmail2/calendar2/admin2 module. (tb-mgw)

More information:
-----------------

Simple Groupware Solutions Thomas Bley
Fichtenstr. 23
Germany, 85640 Putzbrunn

Contact:
--------

info@simple-groupware.de

http://www.simple-groupware.de


Copyright 2002-2003 Thomas Bley
tb-mgw is distributed under the terms of the GNU General Public License 

tb-mgw is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

tb-mgw is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with tb-mgw; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

// Imap_general
// Moregroupware.org


/**
 * imap_general.php
 *
 * Copyright (c) 1999-2002 The SquirrelMail Project Team
 * Licensed under the GNU GPL. For full terms see the file COPYING.
 *
 * This implements all functions that do general imap functions.
 *
 */

/* Sets an unique session id in order to avoid simultanous sessions crash. */
function sqimap_session_id() {
    global $data_dir, $username, $sqimap_session_id;
    return( sprintf("A%03d", $sqimap_session_id++) );
}

/*
 * Both send a command and accept the result from the command.
 * This is to allow proper session number handling.
 */
function sqimap_run_command_list ($imap_stream, $query, $handle_errors, &$response, &$message) {
    $sid = sqimap_session_id();
    fputs ($imap_stream, $sid . ' ' . $query . "\r\n");
    $read = sqimap_read_data_list ($imap_stream, $sid, $handle_errors, $response, $message, $query );
    return $read;
}

function sqimap_run_command ($imap_stream, $query, $handle_errors, &$response, &$message) {
  global $debug;
    $sid = sqimap_session_id();
    fputs ($imap_stream, $sid . ' ' . $query . "\r\n");
    if ($debug) {echo $sid . ' ' . $query . "\r\n<br>";}
    $read = sqimap_read_data ($imap_stream, $sid, $handle_errors, $response, $message, $query);
    return $read;
}


/*
 * Reads the output from the IMAP stream.  If handle_errors is set to true,
 * this will also handle all errors that are received.  If it is not set,
 * the errors will be sent back through $response and $message
 */
function sqimap_read_data_list ($imap_stream, $pre, $handle_errors, &$response, &$message, $query = '') {
    global $color, $squirrelmail_language;

    $read = '';
    $bufsize = 9096;
    $resultlist = array();

    $more_msgs = true;
    while ($more_msgs) {
        $data = array();
        $total_size = 0;

        while (strpos($read, "\n") === false) {
            if(!($read .= fgets($imap_stream, $bufsize))) {
                break;
            }
        }

        /* if (ereg("^\\* [0-9]+ FETCH.*\\{([0-9]+)\\}", $read, $regs)) { */
        if (preg_match('/^\* [0-9]+ FETCH.*\{([0-9]+)\}/', $read, $regs)) {
           $size = $regs[1];
        /* } else if (ereg("^\\* [0-9]+ FETCH", $read, $regs)) { */
        } else if (preg_match('/^\* [0-9]+ FETCH/', $read, $regs)) {
            /* Sizeless response, probably single-line */
            $size = -1;
            $data[] = $read;
            $read = fgets($imap_stream, $bufsize);
        } else {
            $size = -1;
        }
        while (1) {
            while (strpos($read, "\n") === false) {
                if(!($read .= fgets($imap_stream, $bufsize))) {
                    break;
                }
            }
            /* If we know the size, no need to look at the end parameters */
            if ($size > 0) {
                if ($total_size == $size) {
                    /* We've reached the end of this 'message', switch to the next one. */
                    $data[] = $read;
                    break;
                } else if ($total_size > $size) {
                    $difference = $total_size - $size;
                    $total_size = $total_size - strlen($read);
                    $data[] = substr ($read, 0, strlen($read)-$difference);
                    $read = substr ($read, strlen($read)-$difference, strlen($read));
                    break;
                } else {
                    $data[] = $read;
                    $read = fgets($imap_stream, $bufsize);
                    while (strpos($read, "\n") === false) {
                      $read .= fgets($imap_stream, $bufsize);
                    }
                }
                $total_size += strlen($read);
            } else {
                /* if (ereg("^$pre (OK|BAD|NO)(.*)", $read, $regs) || */
                if (preg_match("/^$pre (OK|BAD|NO)(.*)/", $read, $regs) ||
                    /* (($size == -1) && ereg("^\\* [0-9]+ FETCH.*", $read, $regs))) { */
                    (($size == -1) && preg_match('/^\* [0-9]+ FETCH.*/', $read, $regs))) {
                    break;
                } else if ( preg_match('/^\* OK \[PARSE.*/', $read, $regs ) ) {
                    /*
                     * This block has been added in order to avoid the problem
                     * caused by the * OK [PARSE] Missing parameter answer
                     * Please, replace it with a better parsing if you know how.
                     * This block has been updated by
                     * Seth E. Randall <sethr@missoulafcu.org>.  Once we see
                     * one OK [PARSE line, we just go through and keep
                     * tossing them out until we get something different.
                     */
                    while ( preg_match('/^\* OK \[PARSE.*/', $read, $regs ) ) {
                        $read = fgets($imap_stream, $bufsize);
                    }
                    $data[] = $read;
                    $read = fgets ($imap_stream, $bufsize);
                } else if (preg_match('/^\* BYE \[ALERT\](.*)/', $read, $regs)) {
                    /*
                     * It seems that the IMAP server has coughed up a lung
                     * and hung up the connection.  Print any info we have
                     * and abort.
                     */
                    echo "Please contact your system administrator and report the following error:" . "<br>\n";
                    echo $regs[1];
                    exit;
                } else {
                    $data[] = $read;
                    $read = fgets ($imap_stream, $bufsize);
                }
            }
        }

        /*
         * while (($more_msgs = !ereg("^$pre (OK|BAD|NO)(.*)$", $read, $regs)) &&
         * !ereg("^\\* [0-9]+ FETCH.*", $read, $regs)) {
         */
        while (($more_msgs = !preg_match("/^$pre (OK|BAD|NO)(.*)$/", $read, $regs)) &&
            !preg_match('/^\* [0-9]+ FETCH.*/', $read, $regs)) {
            $read = fgets($imap_stream, $bufsize);
        }
        $resultlist[] = $data;
		unset($data);
    }

    $response = $regs[1];
    $message = trim($regs[2]);

    if ($handle_errors == false) { return( $resultlist ); } else if ($response == 'NO') {
        /* ignore this error from M$ exchange, it is not fatal (aka bug) */
        if (strstr($message, 'command resulted in') === false) {
            echo "<br><b><font color=$color[2]>\n" .
                 "ERROR : Could not complete request." .
                 "</b><br>\n" .
                 "Query:" .
                 $query . '<br>' .
                 "Reason Given: " .
                 $message . "</font><br>\n";
            exit;
        }
    } else if ($response == 'BAD') {
        echo "<br><b><font color=$color[2]>\n" .
             "ERROR : Bad or malformed request." .
             "</b><br>\n" .
             "Query:" .
             $query . '<br>' .
             "Server responded: " .
             $message . "</font><br>\n";
        exit;
    } else {
        return $resultlist;
    }
}

function sqimap_read_data_list2 ($imap_stream, $pre, $handle_errors, &$response, &$message, $query = '',$filename) {
    global $color, $squirrelmail_language;

	$fp = fopen("$filename","wb") or die("cannot write $filename"); 

    $read = '';
    $bufsize = 9092;
    $resultlist = array();

    $more_msgs = true;
    while ($more_msgs) {
        $total_size = 0;

        while (strpos($read, "\n") === false) {
            if(!($read .= fgets($imap_stream, $bufsize))) {
                break;
            }
//            fflush($imap_stream);
        }

        /* if (ereg("^\\* [0-9]+ FETCH.*\\{([0-9]+)\\}", $read, $regs)) { */
        if (preg_match('/^\* [0-9]+ FETCH.*\{([0-9]+)\}/', $read, $regs)) {
           $size = $regs[1];
        /* } else if (ereg("^\\* [0-9]+ FETCH", $read, $regs)) { */
        } else if (preg_match('/^\* [0-9]+ FETCH/', $read, $regs)) {
            /* Sizeless response, probably single-line */
            $size = -1;
			if (strpos($read, " FETCH (FLAGS ") === false) {
			  fputs($fp, $read);
			}			
            $read = fgets($imap_stream, $bufsize);
//            fflush($imap_stream);
        } else {
            $size = -1;
        }
		$myi = 0;
        while (1) {
            while (strpos($read, "\n") === false) {
                if(!($read .= fgets($imap_stream, $bufsize))) {
                    break;
                }
//                fflush($imap_stream);
            }
            /* If we know the size, no need to look at the end parameters */
            if ($size > 0) {
                if ($total_size == $size) {
                    /* We've reached the end of this 'message', switch to the next one. */
					fputs($fp, $read);
                    break;
                } else if ($total_size > $size) {
                    $difference = $total_size - $size;
                    $total_size = $total_size - strlen($read);
                    $read = substr ($read, strlen($read)-$difference, strlen($read));
		
					// fputs($fp, $read); ?????
                    break;
                } else {
					if ($myi != 0) {
					  fputs($fp, $read);
					}
                    $read = fgets($imap_stream, $bufsize);
//                    fflush($imap_stream);
					$myi++;
					
                    while (strpos($read, "\n") === false) {
                      $read .= fgets($imap_stream, $bufsize);
                    }
//                    fflush($imap_stream);
                }
                $total_size += strlen($read);
            } else {
                /* if (ereg("^$pre (OK|BAD|NO)(.*)", $read, $regs) || */
                if (preg_match("/^$pre (OK|BAD|NO)(.*)/", $read, $regs) ||
                    /* (($size == -1) && ereg("^\\* [0-9]+ FETCH.*", $read, $regs))) { */
                    (($size == -1) && preg_match('/^\* [0-9]+ FETCH.*/', $read, $regs))) {
                    break;
                } else if ( preg_match('/^\* OK \[PARSE.*/', $read, $regs ) ) {
                    /*
                     * This block has been added in order to avoid the problem
                     * caused by the * OK [PARSE] Missing parameter answer
                     * Please, replace it with a better parsing if you know how.
                     * This block has been updated by
                     * Seth E. Randall <sethr@missoulafcu.org>.  Once we see
                     * one OK [PARSE line, we just go through and keep
                     * tossing them out until we get something different.
                     */
                    while ( preg_match('/^\* OK \[PARSE.*/', $read, $regs ) ) {
                        $read = fgets($imap_stream, $bufsize);
                    }
//                    fflush($imap_stream);
					fputs($fp, $read);
                    $read = fgets ($imap_stream, $bufsize);
//                    fflush($imap_stream);
                } else if (preg_match('/^\* BYE \[ALERT\](.*)/', $read, $regs)) {
                    /*
                     * It seems that the IMAP server has coughed up a lung
                     * and hung up the connection.  Print any info we have
                     * and abort.
                     */
                    echo "Please contact your system administrator and report the following error:" . "<br>\n";
                    echo $regs[1];
                    exit;
                } else {
					fputs($fp, $read);
                    $read = fgets ($imap_stream, $bufsize);
//                    fflush($imap_stream);
                }
            }
        }

        /*
         * while (($more_msgs = !ereg("^$pre (OK|BAD|NO)(.*)$", $read, $regs)) &&
         * !ereg("^\\* [0-9]+ FETCH.*", $read, $regs)) {
         */
        while (($more_msgs = !preg_match("/^$pre (OK|BAD|NO)(.*)$/", $read, $regs)) &&
            !preg_match('/^\* [0-9]+ FETCH.*/', $read, $regs)) {
            $read = fgets($imap_stream, $bufsize);
//            fflush($imap_stream);
        }
    }
	fclose ($fp);

    $response = $regs[1];
    $message = trim($regs[2]);

    if ($handle_errors == false) { return( $resultlist ); } else if ($response == 'NO') {
        /* ignore this error from M$ exchange, it is not fatal (aka bug) */
        if (strstr($message, 'command resulted in') === false) {
            echo "<br><b><font color=$color[2]>\n" .
                 "ERROR : Could not complete request." .
                 "</b><br>\n" .
                 "Query:" .
                 $query . '<br>' .
                 "Reason Given: " .
                 $message . "</font><br>\n";
            exit;
        }
    } else if ($response == 'BAD') {
        echo "<br><b><font color=$color[2]>\n" .
             "ERROR : Bad or malformed request." .
             "</b><br>\n" .
             "Query:" .
             $query . '<br>' .
             "Server responded: ".
             $message . "</font><br>\n";
        exit;
    }
}

function searchattachments($line) {

$ctypecontinue = "";
$ctypelinehold = "";
if (eregi ("^Content-Type:(.*)", $line, $match)) {

		$ctline = trim($match[1]);

   		if(!strpos($ctline,";")) $endpointer = strlen($ctline); else $endpointer = strpos($ctline,";");
    	$ctline = substr($ctline,0,$endpointer);
    	  		
//		echo "<br>".$ctline." ";
}

if (eregi ("^Content-Disposition:(.*)", $line, $match)) {
		$cdline = trim($match[1]);

   		if(!strpos($cdline,";")) $endpointer = strlen($cdline); else $endpointer = strpos($cdline,";");
    	
    	if(eregi("filename", $cdline)) $filename = str_replace("\"","", substr($cdline, 
    	  												strpos($cdline,"=",strpos($cdline,"filename"))+1,
    	  												strlen($cdline)- strpos($cdline,"=")))." ";
		if (strtolower(trim(substr($cdline,0,$endpointer)))=="attachment" or (isset($filename) and $filename!="")) {
		  return true;
		}
}
if (eregi ("filename=(.*)", $line, $match)) {
		$cdline = str_replace("\"","",trim($match[1]));
		if ($cdline!="") {
		  return true;
		}
}
}



function parseContentDispositionLine($cdline)
	{
   		$cdline = trim($cdline);

   		if(!strpos($cdline,";")) $endpointer = strlen($cdline); else $endpointer = strpos($cdline,";");
    	$map["type"] = trim(substr($cdline,0,$endpointer));
    	
    	if(eregi("filename", $cdline)) $map["name"] = str_replace("\"","", substr($cdline, 
    	  												strpos($cdline,"=",strpos($cdline,"filename"))+1,
    	  												strlen($cdline)- strpos($cdline,"=")));
    	return $map;
	}


function sqimap_fgets($imap_stream) {
    $read = '';
    $buffer = 4096;
    $results = '';
    $offset = 0;
    while (strpos($results, "\r\n", $offset) === false) {
        if (!($read = fgets($imap_stream, $buffer))) {
        /* this happens in case of an error */
        /* reset $results because it's useless */
        $results = false;
            break;
        }
        if ( $results != '' ) {
            $offset = strlen($results) - 1;
        }
        $results .= $read;
    }
    return $results;
}

function sqimap_read_data ($imap_stream, $pre, $handle_errors, &$response, &$message, $query = '') {
    $res = sqimap_read_data_list($imap_stream, $pre, $handle_errors, $response, $message, $query);
    return $res[0];
}

function sqimap_login ($username, $password, $imap_server_address, $imap_port, $hide) {
    global $color, $squirrelmail_language, $onetimepad,$imap_conn_error;

    if ($imap_port == 993) {
      $imap_server_address = "ssl://".$imap_server_address;
    }
    
    error_reporting  (E_ERROR | E_PARSE | E_NOTICE);
    $imap_stream = fsockopen ( $imap_server_address, $imap_port, $error_number, $error_string, 15);
    error_reporting  (E_ERROR | E_WARNING | E_PARSE | E_NOTICE);
    
    if ( !$imap_stream ) {
	  $imap_conn_error="failed";
    }


    /* Do some error correction */
    if (!$imap_stream) {
        if (!$hide) {
			$imap_conn_error = "failed (invalid hostname)";
        }
        return false;
		
    } else {

      $server_info = fgets ($imap_stream, 1024);
	  $read = sqimap_run_command ($imap_stream, 'LOGIN "'.quoteIMAP($username).'" "'.quoteIMAP($password).'"', false, $response, $message);

      /* If the connection was not successful, lets see why */
      if ($response != 'OK') {
        if (!$hide) {
            if ($response != 'NO') {
                /* "BAD" and anything else gets reported here. */
                set_up_language($squirrelmail_language, true);
                if ($response == 'BAD') {
                   printf ("Bad request: %s"."<br>\r\n", $message);
                } else {
                   printf ("Unknown error: %s" . "<br>\n", $message);
                }
                echo '<br>' . "Read data:" . "<br>\n";
                if (is_array($read)) {
                    foreach ($read as $line) {
                        echo htmlspecialchars($line) . "<br>\n";
                    }
                }
                exit;
            } else {
                /*
                 * If the user does not log in with the correct
                 * username and password it is not possible to get the
                 * correct locale from the user's preferences.
                 * Therefore, apply the same hack as on the login
                 * screen.
                 *
                 * $squirrelmail_language is set by a cookie when
                 * the user selects language and logs out
                 */
                
                $imap_conn_error = "failed (invalid username/password)";
            }
        } else {
            exit;
        }
      }
      return $imap_stream;
	}
}

/* Simply logs out the IMAP session */
function sqimap_logout ($imap_stream) {
    /* Logout is not valid until the server returns 'BYE' */
    sqimap_run_command($imap_stream, 'LOGOUT', false, $response, $message);
}

function sqimap_capability($imap_stream, $capability) {
    global $sqimap_capabilities;

    if (!is_array($sqimap_capabilities)) {
        $read = sqimap_run_command($imap_stream, 'CAPABILITY', true, $a, $b);

        $c = explode(' ', $read[0]);
        for ($i=2; $i < count($c); $i++) {
            $cap_list = explode('=', $c[$i]);
            if (isset($cap_list[1])) {
                $sqimap_capabilities[$cap_list[0]] = $cap_list[1];
            } else {
                $sqimap_capabilities[$cap_list[0]] = TRUE;
            }
        }
    }
    if (isset($sqimap_capabilities[$capability])) {
        return $sqimap_capabilities[$capability];
    } else {
        return false;
    }
}

/* Returns the delimeter between mailboxes: INBOX/Test, or INBOX.Test */
function sqimap_get_delimiter ($imap_stream = false) {

    $sqimap_delimiter = ".";
    /* Do some caching here */
        if (sqimap_capability($imap_stream, 'NAMESPACE')) {
            /*
             * According to something that I can't find, this is supposed to work on all systems
             * OS: This won't work in Courier IMAP.
             * OS: According to rfc2342 response from NAMESPACE command is:
             * OS: * NAMESPACE (PERSONAL NAMESPACES) (OTHER_USERS NAMESPACE) (SHARED NAMESPACES)
             * OS: We want to lookup all personal NAMESPACES...
             */
            $read = sqimap_run_command($imap_stream, 'NAMESPACE', true, $a, $b);
            if (eregi('\\* NAMESPACE +(\\( *\\(.+\\) *\\)|NIL) +(\\( *\\(.+\\) *\\)|NIL) +(\\( *\\(.+\\) *\\)|NIL)', $read[0], $data)) {
                if (eregi('^\\( *\\((.*)\\) *\\)', $data[1], $data2)) {
                    $pn = $data2[1];
                }
                $pna = explode(')(', $pn);
                while (list($k, $v) = each($pna)) {
                    $lst = explode('"', $v);
                    if (isset($lst[3])) {
                        $pn[$lst[1]] = $lst[3];
                    } else {
                        $pn[$lst[1]] = '';
                    }
                }
            }
            $sqimap_delimiter = $pn[0];
        } else {
            fputs ($imap_stream, ". LIST \"INBOX\" \"\"\r\n");
            $read = sqimap_read_data($imap_stream, '.', true, $a, $b);
            $quote_position = strpos ($read[0], '"');
            $sqimap_delimiter = substr ($read[0], $quote_position+1, 1);
        }
    return $sqimap_delimiter;
}


/* Gets the number of messages in the current mailbox. */
function sqimap_get_num_messages ($imap_stream, $mailbox) {
    $read_ary = sqimap_run_command ($imap_stream, "Examine \"$mailbox\"", false, $result, $message);

    for ($i = 0; $i < count($read_ary); $i++) {
        if (ereg("[^ ]+ +([^ ]+) +EXISTS", $read_ary[$i], $regs)) {
            return $regs[1];
        }
    }
    return 0;
}


/* Returns a displayable email address.
 *     Luke Ehresman <lehresma@css.tayloru.edu>
 *     "Luke Ehresman" <lehresma@css.tayloru.edu>
 *     <lehresma@css.tayloru.edu>
 *     lehresma@css.tayloru.edu (Luke Ehresman)
 *     lehresma@css.tayloru.edu
 * becomes: lehresma@css.tayloru.edu
 */
function sqimap_find_email ($string) {
    if (ereg("<([^>]+)>", $string, $regs)) {
        $string = $regs[1];
    } else if (ereg("([^ ]+@[^ ]+)", $string, $regs)) {
        $string = $regs[1];
    }
    return trim($string);
}


/*
 * Takes the From: field and creates a displayable name.
 *     Luke Ehresman   <lkehresman@yahoo.com>
 *     "Luke Ehresman" <lkehresman@yahoo.com>
 *     lkehresman@yahoo.com (Luke Ehresman)
 * becomes: Luke Ehresman
 *     <lkehresman@yahoo.com>
 * becomes: lkehresman@yahoo.com
 */
function sqimap_find_displayable_name ($string) {
    $string = trim($string);

    if ( ereg('^(.+)<.*>', $string, $regs) ) {
        $orig_string = $string;
        $string = str_replace ('"', '', $regs[1] );
        if (trim($string) == '') {
             $string = sqimap_find_email($orig_string);
        }
        if( $string == '' || $string == ' ' ){
            $string = '&nbsp';
        }
    }
    elseif ( ereg('\((.*)\)', $string, $regs) ) {
        if( ( $regs[1] == '' ) || ( $regs[1] == ' ' ) ){
            if ( ereg('^(.+) \(', $string, $regs) ) {
               $string = ereg_replace( ' \(\)$', '', $string );
            } else {
               $string = '&nbsp';
            }
        } else {
            $string = $regs[1];
        }
    }
    else {
        $string = str_replace ('"', '', sqimap_find_email($string));
    }

    return trim($string);
}

/*
 * Returns the number of unseen messages in this folder
 */
function sqimap_unseen_messages ($imap_stream, $mailbox) {
    $read_ary = sqimap_run_command ($imap_stream, "STATUS \"$mailbox\" (UNSEEN)", true, $result, $message);
    $i = 0;
    while (isset($read_ary[$i])) {
        if (ereg("UNSEEN ([0-9]+)", $read_ary[$i], $regs)) {
            break;
        }
        $i++;
    }
    return $regs[1];
}


/*
 *  Saves a message to a given folder -- used for saving sent messages
 */
function sqimap_append ($imap_stream, $sent_folder, $length) {
    fputs ($imap_stream, sqimap_session_id() . " APPEND \"$sent_folder\" (\\Seen) \{$length}\r\n");
    $tmp = fgets ($imap_stream, 1024);
}

function sqimap_append_done ($imap_stream) {
    fputs ($imap_stream, "\r\n");
    $tmp = fgets ($imap_stream, 1024);
    if (preg_match("/(.*)(BAD|NO)(.*)$/", $tmp, $regs)) {
        $reason = $regs[3];
        if ($regs[2] == 'NO') {
           $string = "ERROR : Could not append message. Server responded: ".$reason."<br>";
           if (preg_match("/(.*)(quota)(.*)$/i", $reason, $regs)) {
              $string .= "Solution: Remove unneccessary messages from your folder and start with your Trash folder.<br>" ;
           }
		   die($string);
        } else {
           die("ERROR : Bad or malformed request. Server responded: ".$tmp);
        }
	}
}

function sqimap_get_message ($imap_stream, $id) {
    $read = sqimap_run_command ($imap_stream, "FETCH $id (BODYSTRUCTURE)", true, $result, $message);
    if (!$read) { $bodystructure = ""; } 
      else { $bodystructure = implode('',$read); }
    return $bodystructure;
}

?>
